==> plugin-android-5.4.3-sources.jar: com/zoyi/channel/plugin/android/view/dialog/CountryCodeDialog.java <==
package com.zoyi.channel.plugin.android.view.dialog;

import android.content.Context;
import android.content.DialogInterface;
import android.support.annotation.NonNull;
import android.support.v7.app.AlertDialog;

import com.zoyi.channel.plugin.android.model.rest.Country;
import com.zoyi.channel.plugin.android.selector.CountrySelector;
import com.zoyi.channel.plugin.android.util.CompareUtils;

import java.util.ArrayList;
import java.util.List;

public class CountryCodeDialog extends AlertDialog.Builder {

  public interface OnCountryCodeSelectListener {

    void onCountryCodeSelected(int position, String countryCode);
  }

  public CountryCodeDialog(@NonNull Context context, String country, final OnCountryCodeSelectListener listener) {
    super(context);

    final List<Country> countries = CountrySelector.get();

    setSingleChoiceItems(getItems(countries), getItemPosition(country, countries), new DialogInterface.OnClickListener() {
      @Override
      public void onClick(DialogInterface dialog, int which) {
        if (listener != null) {
          listener.onCountryCodeSelected(which, countries.get(which).getCallingCode());
        }
        dialog.dismiss();
      }
    });
  }

  private String[] getItems(List<Country> countries) {
    ArrayList<String> items = new ArrayList<>();

    for (Country country : countries) {
      items.add(String.format("%s (+%s)", country.getName(), country.getCallingCode()));
    }
    return items.toArray(new String[items.size()]);
  }

  private int getItemPosition(String countryName, List<Country> countries) {
    int position = 0;

    for (int i = 0; i < countries.size(); i++) {
      if (CompareUtils.isSame(countries.get(i).getName(), countryName)) {
        position = i;
        break;
      }
    }
    return position;
  }
}

==> plugin-android-8.0.0-sources.jar: com/zoyi/channel/plugin/android/view/dialog/CountryCodeDialog.java <==
package com.zoyi.channel.plugin.android.view.dialog;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.v7.app.AlertDialog;
import com.zoyi.channel.plugin.android.model.rest.Country;
import com.zoyi.channel.plugin.android.util.CompareUtils;

import java.util.ArrayList;
import java.util.List;

public class CountryCodeDialog extends AlertDialog.Builder {

  public interface OnCountryCodeSelectListener {

    void onCountryCodeSelected(int position, String countryCode);
  }

  public CountryCodeDialog(@NonNull Context context, List<Country> countries, @Nullable OnCountryCodeSelectListener listener) {
    super(context);

    setSingleChoiceItems(getItems(countries), -1, (dialog, which) -> {
      if (listener != null) {
        listener.onCountryCodeSelected(which, countries.get(which).getCallingCode());
      }
      dialog.dismiss();
    });
  }

  private String[] getItems(List<Country> countries) {
    ArrayList<String> items = new ArrayList<>();

    for (Country country : countries) {
      items.add(String.format("%s (+%s)", country.getName(), country.getCallingCode()));
    }
    return items.toArray(new String[items.size()]);
  }

  private int getItemPosition(String countryName, List<Country> countries) {
    int position = 0;

    for (int i = 0; i < countries.size(); i++) {
      if (CompareUtils.isSame(countries.get(i).getName(), countryName)) {
        position = i;
        break;
      }
    }
    return position;
  }
}
